ipythontools
============

.. automodule:: abjad.tools.ipythontools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.ipythontools.IPythonConfiguration.IPythonConfiguration
      ~abjad.tools.ipythontools.Play.Play
      ~abjad.tools.ipythontools.Show.Show
